@@ -8,11 +8,8 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package MooseX::Types::Tied;
-BEGIN {
-  $MooseX::Types::Tied::AUTHORITY = 'cpan:RSRCHBOY';
-}
-BEGIN {
-  $MooseX::Types::Tied::VERSION = '0.002';
+{
+  $MooseX::Types::Tied::VERSION = '0.003';
 }
 
 # ABSTRACT: Basic tied Moose types library
@@ -55,13 +52,15 @@ subtype TiedHandle,
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 MooseX::Types::Tied - Basic tied Moose types library
 
 =head1 VERSION
 
-version 0.002
+This document describes version 0.003 of MooseX::Types::Tied - released April 21, 2012 as part of MooseX-Types-Tied.
 
 =head1 SYNOPSIS
 
@@ -78,23 +77,39 @@ This is a collection of basic L<Moose> types for tied references.  The package
 behaves as you'd expect a L<MooseX::Types> library to act: either specify the
 types you want imported explicitly or use the ':all' catchall.
 
+=for stopwords TiedArray TiedHash TiedHandle
+
 =head1 TYPES
 
 =head2 Tied
 
-Basetype: Ref (to Scalar)
+Base type: Ref (to Scalar)
 
 =head2 TiedArray
 
-Basetype: ArrayRef
+Base type: ArrayRef
 
 =head2 TiedHash
 
-Basetype: HashRef
+Base type: HashRef
 
 =head2 TiedHandle
 
-Basetype: FileHandle
+Base type: FileHandle
+
+=head1 SOURCE
+
+The development version is on github at L<http://github.com/RsrchBoy/moosex-types-tied>
+and may be cloned from L<git://github.com/RsrchBoy/moosex-types-tied.git>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/RsrchBoy/moosex-types-tied/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
